package com.develop.foodcooking

import android.annotation.SuppressLint
import android.content.Intent
import android.net.Uri
import android.os.PowerManager
import android.os.PowerManager.WakeLock
import android.provider.Settings
import com.develop.food.base.FoodCookBaseApp
import com.develop.food.base.router.ARouterUtils
import com.develop.food.base.utils.AppVerUtils
import com.develop.food.base.utils.MmkvUtils
import com.develop.food.base.utils.NetWorkManager
import com.kuyuntech.cofarcooking.device.sdk.constant.core.DevStatus
import com.kuyuntech.cofarcooking.device.sdk.eventbus.event.DevStatusEvent
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK
import com.tencent.bugly.crashreport.CrashReport
import org.greenrobot.eventbus.Subscribe
import java.util.*


class FoodCookApp : FoodCookBaseApp() {
    var mWakeLock: PowerManager.WakeLock? = null



    override fun onCreate() {
        super.onCreate()
        MmkvUtils.initialize(this)
        ARouterUtils.init(this, BuildConfig.DEBUG)
        CrashReport.initCrashReport(this, "0c1b27f35b", BuildConfig.DEBUG)
        SerialportUtils.init()
        CofarSDK.register(this)
        CofarSDK.stopNative()
        val mContext = applicationContext
        val powerManager = mContext.getSystemService(android.content.Context.POWER_SERVICE) as PowerManager
        val  wakeLock: WakeLock = powerManager.newWakeLock(PowerManager.PARTIAL_WAKE_LOCK, "motionDetection:keepAwake")
        wakeLock.acquire()
        NetWorkManager.get().init(this)
        AppVerUtils.checkRecipeUpdate()
        var minute = MmkvUtils.getInt("ScreenSaver")
        if(minute == 0){
            minute = 3;
        }
        Settings.System.putInt(
            contentResolver,
            Settings.System.SCREEN_OFF_TIMEOUT,
            (1000 * 60 * minute).toInt()
        )
        val uri: Uri = Settings.System
            .getUriFor(Settings.System.SCREEN_OFF_TIMEOUT)
        contentResolver.notifyChange(uri, null)
    }





    var keepScreen = false

    var  timer:Timer ?= null;

    var ledLock = false;

    @SuppressLint("InvalidWakeLockTag")
    @Subscribe
    @Synchronized
    fun devMsg(event: DevStatusEvent){

//        return
        val devInfo = event.devInfo;
        val pm = getSystemService(POWER_SERVICE) as PowerManager
        var minute = MmkvUtils.getInt("ScreenSaver")
        if(minute == 0){
            minute = 3;
        }

        if(devInfo.status == DevStatus.RUNNING.toInt() || devInfo.isWeightStatus){
            if(mWakeLock == null){
                mWakeLock = pm.newWakeLock(PowerManager.SCREEN_BRIGHT_WAKE_LOCK or PowerManager.ON_AFTER_RELEASE or PowerManager.ACQUIRE_CAUSES_WAKEUP, "tag");
                mWakeLock?.setReferenceCounted(false);
                mWakeLock?.acquire()
            }


        }else if (devInfo.status != DevStatus.RUNNING.toInt()){
            if(mWakeLock != null){
                mWakeLock?.release()
                mWakeLock = null
                val intent = Intent()
                intent.action = "android.intent.action.SS_DEVICE_TOUCH"
                sendBroadcast(intent)
            }

        }




        if(!ledLock){
            ledLock = true;
            if(!pm.isScreenOn){

                //合盖
                if(devInfo.potCloverStatus.toInt() == 0){
                    CofarSDK.flashWhiteRedLed()
                }else{
                    CofarSDK.switchWhiteLed('0');
                    CofarSDK.flashRedLed()
                }

            }else{
                if (devInfo.status == DevStatus.STOP.toInt()) {

                    if (devInfo.potStatus.toInt() == 0) {
                        if(devInfo.potCloverStatus.toInt() == 0){
                            CofarSDK.flashWhiteRedLed()
                        }else{
                            CofarSDK.switchWhiteLed('0');
                            CofarSDK.flashRedLed()
                        }
                    } else {
                        CofarSDK.flashWhiteRedLed();
                    }

                }

                if (devInfo.status == DevStatus.RUNNING.toInt()) {

                    if (devInfo.temp < 60) {
                        CofarSDK.switchRedLed('0');
                        CofarSDK.switchWhiteLed('1');
                    } else {
                        CofarSDK.switchRedLed('1');
                        CofarSDK.switchWhiteLed('0');
                    }

                }

                if (devInfo.status == DevStatus.PAUSE.toInt()) {

                    //判断盖子是否打开
                    //合盖
                    if(devInfo.potCloverStatus.toInt() == 1){
                        CofarSDK.switchWhiteLed('0');
                        CofarSDK.flashRedLed()
                    }else{
                        CofarSDK.flashWhiteRedLed()
                    }


                }
            }
            ledLock = false;
        }



        println(pm.isScreenOn)

    }



}